aboutsummaryrefslogtreecommitdiffstats
path: root/src/drivers/net/myri10ge.c
diff options
context:
space:
mode:
authorMichael Brown <mcb30@ipxe.org>2020-11-05 19:08:48 +0000
committerMichael Brown <mcb30@ipxe.org>2020-11-05 19:13:52 +0000
commitbe1c87b72237f633c4f4b05bcb133acf2967d788 (patch)
treeadc9bc36da62d55f0f1f5708af7c66d1cc3af949 /src/drivers/net/myri10ge.c
parent36dde9b0bf27ae411af677ca1fa3075113133cfe (diff)
downloadipxe-be1c87b72237f633c4f4b05bcb133acf2967d788.tar.gz
[malloc] Rename malloc_dma() to malloc_phys()
The malloc_dma() function allocates memory with specified physical alignment, and is typically (though not exclusively) used to allocate memory for DMA. Rename to malloc_phys() to more closely match the functionality, and to create name space for functions that specifically allocate and map DMA-capable buffers. Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'src/drivers/net/myri10ge.c')
-rw-r--r--src/drivers/net/myri10ge.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/drivers/net/myri10ge.c b/src/drivers/net/myri10ge.c
index ae6b6c21e..6d0f723f2 100644
--- a/src/drivers/net/myri10ge.c
+++ b/src/drivers/net/myri10ge.c
@@ -66,7 +66,7 @@ FILE_LICENCE ( GPL2_ONLY );
/*
* Debugging levels:
* - DBG() is for any errors, i.e. failed alloc_iob(), malloc_dma(),
* TX overflow, corrupted packets, ...
* - DBG2() is for successful events, like packet received,
* packet transmitted, and other general notifications.
@@ -918,7 +918,7 @@ static void myri10ge_net_close ( struct net_device *netdev )
/* Release DMAable memory. */
- free_dma ( priv->dma, sizeof ( *priv->dma ) );
+ free_phys ( priv->dma, sizeof ( *priv->dma ) );
/* Erase all state from the open. */
@@ -988,7 +988,7 @@ static int myri10ge_net_open ( struct net_device *netdev )
/* Allocate cleared DMAable buffers. */
- priv->dma = malloc_dma ( sizeof ( *priv->dma ) , 128 );
+ priv->dma = malloc_phys ( sizeof ( *priv->dma ) , 128 );
if ( !priv->dma ) {
rc = -ENOMEM;
dbg = "DMA";
@@ -1152,7 +1152,7 @@ abort_with_receives_posted:
free_iob ( priv->receive_iob[priv->receives_posted] );
abort_with_dma:
/* Because the link is not up, we don't have to reset the NIC here. */
- free_dma ( priv->dma, sizeof ( *priv->dma ) );
+ free_phys ( priv->dma, sizeof ( *priv->dma ) );
abort_with_nothing:
/* Erase all signs of the failed open. */
memset ( priv, 0, sizeof ( *priv ) );
@@ -66,7 +66,7 @@ FILE_LICENCE ( GPL2_ONLY );
/*
* Debugging levels:
- * - DBG() is for any errors, i.e. failed alloc_iob(), malloc_dma(),
+ * - DBG() is for any errors, i.e. failed alloc_iob(), malloc_phys(),
* TX overflow, corrupted packets, ...
* - DBG2() is for successful events, like packet received,